@@ -1306,66 +1306,6 @@ typedef struct VBOXVDMA_CTL {
 	s32  result;
 } VBOXVDMA_CTL;
 
-typedef struct VBOXVDMA_RECTL {
-	int16_t left;
-	int16_t top;
-	u16 width;
-	u16 height;
-} VBOXVDMA_RECTL, *PVBOXVDMA_RECTL;
-
-typedef enum {
-	VBOXVDMA_PIXEL_FORMAT_UNKNOWN      =  0,
-	VBOXVDMA_PIXEL_FORMAT_R8G8B8       = 20,
-	VBOXVDMA_PIXEL_FORMAT_A8R8G8B8     = 21,
-	VBOXVDMA_PIXEL_FORMAT_X8R8G8B8     = 22,
-	VBOXVDMA_PIXEL_FORMAT_R5G6B5       = 23,
-	VBOXVDMA_PIXEL_FORMAT_X1R5G5B5     = 24,
-	VBOXVDMA_PIXEL_FORMAT_A1R5G5B5     = 25,
-	VBOXVDMA_PIXEL_FORMAT_A4R4G4B4     = 26,
-	VBOXVDMA_PIXEL_FORMAT_R3G3B2       = 27,
-	VBOXVDMA_PIXEL_FORMAT_A8           = 28,
-	VBOXVDMA_PIXEL_FORMAT_A8R3G3B2     = 29,
-	VBOXVDMA_PIXEL_FORMAT_X4R4G4B4     = 30,
-	VBOXVDMA_PIXEL_FORMAT_A2B10G10R10  = 31,
-	VBOXVDMA_PIXEL_FORMAT_A8B8G8R8     = 32,
-	VBOXVDMA_PIXEL_FORMAT_X8B8G8R8     = 33,
-	VBOXVDMA_PIXEL_FORMAT_G16R16       = 34,
-	VBOXVDMA_PIXEL_FORMAT_A2R10G10B10  = 35,
-	VBOXVDMA_PIXEL_FORMAT_A16B16G16R16 = 36,
-	VBOXVDMA_PIXEL_FORMAT_A8P8         = 40,
-	VBOXVDMA_PIXEL_FORMAT_P8           = 41,
-	VBOXVDMA_PIXEL_FORMAT_L8           = 50,
-	VBOXVDMA_PIXEL_FORMAT_A8L8         = 51,
-	VBOXVDMA_PIXEL_FORMAT_A4L4         = 52,
-	VBOXVDMA_PIXEL_FORMAT_V8U8         = 60,
-	VBOXVDMA_PIXEL_FORMAT_L6V5U5       = 61,
-	VBOXVDMA_PIXEL_FORMAT_X8L8V8U8     = 62,
-	VBOXVDMA_PIXEL_FORMAT_Q8W8V8U8     = 63,
-	VBOXVDMA_PIXEL_FORMAT_V16U16       = 64,
-	VBOXVDMA_PIXEL_FORMAT_W11V11U10    = 65,
-	VBOXVDMA_PIXEL_FORMAT_A2W10V10U10  = 67
-} VBOXVDMA_PIXEL_FORMAT;
-
-typedef struct VBOXVDMA_SURF_DESC {
-	u32 width;
-	u32 height;
-	VBOXVDMA_PIXEL_FORMAT format;
-	u32 bpp;
-	u32 pitch;
-	u32 flags;
-} VBOXVDMA_SURF_DESC, *PVBOXVDMA_SURF_DESC;
-
-/*typedef uint64_t VBOXVDMAPHADDRESS;*/
-typedef uint64_t VBOXVDMASURFHANDLE;
-
-/* region specified as a rectangle, otherwize it is a size of memory pointed to by phys address */
-#define VBOXVDMAOPERAND_FLAGS_RECTL       0x1
-/* Surface handle is valid */
-#define VBOXVDMAOPERAND_FLAGS_PRIMARY        0x2
-/* address is offset in VRAM */
-#define VBOXVDMAOPERAND_FLAGS_VRAMOFFSET  0x4
-
-
 /* VBOXVDMACBUF_DR::phBuf specifies offset in VRAM */
 #define VBOXVDMACBUF_FLAG_BUF_VRAM_OFFSET 0x00000001
 /* command buffer follows the VBOXVDMACBUF_DR in VRAM, VBOXVDMACBUF_DR::phBuf is ignored */
@@ -1414,65 +1354,9 @@ typedef struct VBOXVDMACMD {
 	( (VBOXVDMACMD  *)( ((u8 *)(a_pBody)) - VBOXVDMACMD_HEADER_SIZE()) )
 #define VBOXVDMACMD_BODY_FIELD_OFFSET(_ot, _t, _f)  ( (_ot)(uintptr_t)( VBOXVDMACMD_BODY(0, u8) + RT_UOFFSETOF_DYN(_t, _f) ) )
 
-typedef struct VBOXVDMACMD_DMA_PRESENT_BLT {
-	VBOXVIDEOOFFSET offSrc;
-	VBOXVIDEOOFFSET offDst;
-	VBOXVDMA_SURF_DESC srcDesc;
-	VBOXVDMA_SURF_DESC dstDesc;
-	VBOXVDMA_RECTL srcRectl;
-	VBOXVDMA_RECTL dstRectl;
-	u32 reserved;
-	u32 cDstSubRects;
-	VBOXVDMA_RECTL aDstSubRects[1];
-} VBOXVDMACMD_DMA_PRESENT_BLT, *PVBOXVDMACMD_DMA_PRESENT_BLT;
+# pragma pack()
+#endif /* #ifdef VBOX_WITH_VDMA */
 
-typedef struct VBOXVDMACMD_DMA_PRESENT_SHADOW2PRIMARY {
-	VBOXVDMA_RECTL Rect;
-} VBOXVDMACMD_DMA_PRESENT_SHADOW2PRIMARY, *PVBOXVDMACMD_DMA_PRESENT_SHADOW2PRIMARY;
-
-
-#define VBOXVDMACMD_DMA_BPB_TRANSFER_F_SRC_VRAMOFFSET 0x00000001
-#define VBOXVDMACMD_DMA_BPB_TRANSFER_F_DST_VRAMOFFSET 0x00000002
-
-typedef struct VBOXVDMACMD_DMA_BPB_TRANSFER {
-	u32 cbTransferSize;
-	u32 flags;
-	union {
-		uint64_t phBuf;
-		VBOXVIDEOOFFSET offVramBuf;
-	} Src;
-	union {
-		uint64_t phBuf;
-		VBOXVIDEOOFFSET offVramBuf;
-	} Dst;
-} VBOXVDMACMD_DMA_BPB_TRANSFER, *PVBOXVDMACMD_DMA_BPB_TRANSFER;
-
-#define VBOXVDMACMD_SYSMEMEL_F_PAGELIST 0x00000001
-
-typedef struct VBOXVDMACMD_SYSMEMEL {
-	u32 cPages;
-	u32 flags;
-	uint64_t phBuf[1];
-} VBOXVDMACMD_SYSMEMEL, *PVBOXVDMACMD_SYSMEMEL;
-
-#define VBOXVDMACMD_SYSMEMEL_NEXT(_pEl) ( ((_pEl)->flags & VBOXVDMACMD_SYSMEMEL_F_PAGELIST) \
-		? ((PVBOXVDMACMD_SYSMEMEL)(((u8*)(_pEl)) + RT_UOFFSETOF_DYN(VBOXVDMACMD_SYSMEMEL, phBuf[(_pEl)->cPages]))) \
-		: ((_pEl) + 1) )
-
-#define VBOXVDMACMD_DMA_BPB_TRANSFER_VRAMSYS_SYS2VRAM 0x00000001
-
-typedef struct VBOXVDMACMD_DMA_BPB_TRANSFER_VRAMSYS {
-	u32 cTransferPages;
-	u32 flags;
-	VBOXVIDEOOFFSET offVramBuf;
-	VBOXVDMACMD_SYSMEMEL FirstEl;
-} VBOXVDMACMD_DMA_BPB_TRANSFER_VRAMSYS, *PVBOXVDMACMD_DMA_BPB_TRANSFER_VRAMSYS;
-
-typedef struct VBOXVDMACMD_DMA_BPB_FILL {
-	VBOXVIDEOOFFSET offSurf;
-	u32 cbFillSize;
-	u32 u32FillPattern;
-} VBOXVDMACMD_DMA_BPB_FILL, *PVBOXVDMACMD_DMA_BPB_FILL;
 
 #define VBOXVDMA_CHILD_STATUS_F_CONNECTED    0x01
 #define VBOXVDMA_CHILD_STATUS_F_DISCONNECTED 0x02
@@ -1494,472 +1378,8 @@ typedef struct VBOXVDMACMD_CHILD_STATUS_IRQ {
 	VBOXVDMA_CHILD_STATUS aInfos[1];
 } VBOXVDMACMD_CHILD_STATUS_IRQ, *PVBOXVDMACMD_CHILD_STATUS_IRQ;
 
-# pragma pack()
-#endif /* #ifdef VBOX_WITH_VDMA */
-
-#pragma pack(1)
-typedef struct VBOXVDMACMD_CHROMIUM_BUFFER {
-	VBOXVIDEOOFFSET offBuffer;
-	u32 buffer_length;
-	u32 u32GuestData;
-	uint64_t u64GuestData;
-} VBOXVDMACMD_CHROMIUM_BUFFER, *PVBOXVDMACMD_CHROMIUM_BUFFER;
-
-typedef struct VBOXVDMACMD_CHROMIUM_CMD {
-	u32 cBuffers;
-	u32 reserved;
-	VBOXVDMACMD_CHROMIUM_BUFFER aBuffers[1];
-} VBOXVDMACMD_CHROMIUM_CMD, *PVBOXVDMACMD_CHROMIUM_CMD;
-
-typedef enum {
-	VBOXVDMACMD_CHROMIUM_CTL_TYPE_UNKNOWN = 0,
-	VBOXVDMACMD_CHROMIUM_CTL_TYPE_CRHGSMI_SETUP,
-	VBOXVDMACMD_CHROMIUM_CTL_TYPE_SAVESTATE_BEGIN,
-	VBOXVDMACMD_CHROMIUM_CTL_TYPE_SAVESTATE_END,
-	VBOXVDMACMD_CHROMIUM_CTL_TYPE_CRHGSMI_SETUP_MAINCB,
-	VBOXVDMACMD_CHROMIUM_CTL_TYPE_CRCONNECT,
-	VBOXVDMACMD_CHROMIUM_CTL_TYPE_SIZEHACK = 0x7fffffff
-} VBOXVDMACMD_CHROMIUM_CTL_TYPE;
-
-typedef struct VBOXVDMACMD_CHROMIUM_CTL {
-	VBOXVDMACMD_CHROMIUM_CTL_TYPE enmType;
-	u32 cbCmd;
-} VBOXVDMACMD_CHROMIUM_CTL, *PVBOXVDMACMD_CHROMIUM_CTL;
-
-
-typedef struct PDMIDISPLAYVBVACALLBACKS *HCRHGSMICMDCOMPLETION;
-typedef int FNCRHGSMICMDCOMPLETION(HCRHGSMICMDCOMPLETION hCompletion, PVBOXVDMACMD_CHROMIUM_CMD pCmd, int rc);
-typedef FNCRHGSMICMDCOMPLETION *PFNCRHGSMICMDCOMPLETION;
-
-/* tells whether 3D backend has some 3D overlay data displayed */
-typedef bool FNCROGLHASDATA(void);
-typedef FNCROGLHASDATA *PFNCROGLHASDATA;
-
-/* same as PFNCROGLHASDATA, but for specific screen */
-typedef bool FNCROGLHASDATAFORSCREEN(u32 i32ScreenID);
-typedef FNCROGLHASDATAFORSCREEN *PFNCROGLHASDATAFORSCREEN;
-
-/* callbacks chrogl gives to main */
-typedef struct CR_MAIN_INTERFACE {
-	PFNCROGLHASDATA pfnHasData;
-	PFNCROGLHASDATAFORSCREEN pfnHasDataForScreen;
-} CR_MAIN_INTERFACE;
-
-typedef struct VBOXVDMACMD_CHROMIUM_CTL_CRHGSMI_SETUP_MAINCB {
-	VBOXVDMACMD_CHROMIUM_CTL Hdr;
-	/*in*/
-	HCRHGSMICMDCOMPLETION hCompletion;
-	PFNCRHGSMICMDCOMPLETION pfnCompletion;
-	/*out*/
-	CR_MAIN_INTERFACE MainInterface;
-} VBOXVDMACMD_CHROMIUM_CTL_CRHGSMI_SETUP_MAINCB, *PVBOXVDMACMD_CHROMIUM_CTL_CRHGSMI_SETUP_MAINCB;
-
-typedef struct VBOXCRCON_SERVER *HVBOXCRCON_SERVER;
-typedef struct PDMIDISPLAYVBVACALLBACKS* HVBOXCRCON_CLIENT;
-
-typedef struct VBOXCRCON_3DRGN_CLIENT* HVBOXCRCON_3DRGN_CLIENT;
-typedef struct VBOXCRCON_3DRGN_ASYNCCLIENT* HVBOXCRCON_3DRGN_ASYNCCLIENT;
-
-/* server callbacks */
-/* submit chromium cmd */
-typedef int FNVBOXCRCON_SVR_CRCMD(HVBOXCRCON_SERVER hServer, PVBOXVDMACMD_CHROMIUM_CMD pCmd, u32 cbCmd);
-typedef FNVBOXCRCON_SVR_CRCMD *PFNVBOXCRCON_SVR_CRCMD;
-
-/* submit chromium control cmd */
-typedef int FNVBOXCRCON_SVR_CRCTL(HVBOXCRCON_SERVER hServer, PVBOXVDMACMD_CHROMIUM_CTL pCtl, u32 cbCmd);
-typedef FNVBOXCRCON_SVR_CRCTL *PFNVBOXCRCON_SVR_CRCTL;
-
-/* request 3D data.
- * The protocol is the following:
- * 1. if there is no 3D data displayed on screen, returns VINF_EOF immediately w/o calling any PFNVBOXCRCON_3DRGN_XXX callbacks
- * 2. otherwise calls PFNVBOXCRCON_3DRGN_ONSUBMIT, submits the "regions get" request to the CrOpenGL server to process it asynchronously and returns VINF_SUCCESS
- * 2.a on "regions get" request processing calls PFNVBOXCRCON_3DRGN_BEGIN,
- * 2.b then PFNVBOXCRCON_3DRGN_REPORT zero or more times for each 3D region,
- * 2.c and then PFNVBOXCRCON_3DRGN_END
- * 3. returns VERR_XXX code on failure
- * */
-typedef int FNVBOXCRCON_SVR_3DRGN_GET(HVBOXCRCON_SERVER hServer, HVBOXCRCON_3DRGN_CLIENT hRgnClient, u32 idScreen);
-typedef FNVBOXCRCON_SVR_3DRGN_GET *PFNVBOXCRCON_SVR_3DRGN_GET;
-
-/* 3D Regions Client callbacks */
-/* called from the PFNVBOXCRCON_SVR_3DRGN_GET callback in case server has 3D data and is going to process the request asynchronously,
- * see comments for PFNVBOXCRCON_SVR_3DRGN_GET above */
-typedef int FNVBOXCRCON_3DRGN_ONSUBMIT(HVBOXCRCON_3DRGN_CLIENT hRgnClient, u32 idScreen, HVBOXCRCON_3DRGN_ASYNCCLIENT *phRgnAsyncClient);
-typedef FNVBOXCRCON_3DRGN_ONSUBMIT *PFNVBOXCRCON_3DRGN_ONSUBMIT;
-
-/* called from the "regions get" command processing thread, to indicate that the "regions get" is started.
- * see comments for PFNVBOXCRCON_SVR_3DRGN_GET above */
-typedef int FNVBOXCRCON_3DRGN_BEGIN(HVBOXCRCON_3DRGN_ASYNCCLIENT hRgnAsyncClient, u32 idScreen);
-typedef FNVBOXCRCON_3DRGN_BEGIN *PFNVBOXCRCON_3DRGN_BEGIN;
-
-/* called from the "regions get" command processing thread, to report a 3D region.
- * see comments for PFNVBOXCRCON_SVR_3DRGN_GET above */
-typedef int FNVBOXCRCON_3DRGN_REPORT(HVBOXCRCON_3DRGN_ASYNCCLIENT hRgnAsyncClient, u32 idScreen, void *pvData, u32 cbStride, const void *pRect);
-typedef FNVBOXCRCON_3DRGN_REPORT *PFNVBOXCRCON_3DRGN_REPORT;
-
-/* called from the "regions get" command processing thread, to indicate that the "regions get" is completed.
- * see comments for PFNVBOXCRCON_SVR_3DRGN_GET above */
-typedef int FNVBOXCRCON_3DRGN_END(HVBOXCRCON_3DRGN_ASYNCCLIENT hRgnAsyncClient, u32 idScreen);
-typedef FNVBOXCRCON_3DRGN_END *PFNVBOXCRCON_3DRGN_END;
-
-
-/* client callbacks */
-/* complete chromium cmd */
-typedef int FNVBOXCRCON_CLT_CRCTL_COMPLETE(HVBOXCRCON_CLIENT hClient, PVBOXVDMACMD_CHROMIUM_CTL pCtl, int rc);
-typedef FNVBOXCRCON_CLT_CRCTL_COMPLETE *PFNVBOXCRCON_CLT_CRCTL_COMPLETE;
-
-/* complete chromium control cmd */
-typedef int FNVBOXCRCON_CLT_CRCMD_COMPLETE(HVBOXCRCON_CLIENT hClient, PVBOXVDMACMD_CHROMIUM_CMD pCmd, int rc);
-typedef FNVBOXCRCON_CLT_CRCMD_COMPLETE *PFNVBOXCRCON_CLT_CRCMD_COMPLETE;
-
-typedef struct VBOXCRCON_SERVER_CALLBACKS {
-	HVBOXCRCON_SERVER hServer;
-	PFNVBOXCRCON_SVR_CRCMD pfnCrCmd;
-	PFNVBOXCRCON_SVR_CRCTL pfnCrCtl;
-	PFNVBOXCRCON_SVR_3DRGN_GET pfn3DRgnGet;
-} VBOXCRCON_SERVER_CALLBACKS, *PVBOXCRCON_SERVER_CALLBACKS;
-
-typedef struct VBOXCRCON_CLIENT_CALLBACKS {
-	HVBOXCRCON_CLIENT hClient;
-	PFNVBOXCRCON_CLT_CRCMD_COMPLETE pfnCrCmdComplete;
-	PFNVBOXCRCON_CLT_CRCTL_COMPLETE pfnCrCtlComplete;
-	PFNVBOXCRCON_3DRGN_ONSUBMIT pfn3DRgnOnSubmit;
-	PFNVBOXCRCON_3DRGN_BEGIN pfn3DRgnBegin;
-	PFNVBOXCRCON_3DRGN_REPORT pfn3DRgnReport;
-	PFNVBOXCRCON_3DRGN_END pfn3DRgnEnd;
-} VBOXCRCON_CLIENT_CALLBACKS, *PVBOXCRCON_CLIENT_CALLBACKS;
-
-/* issued by Main to establish connection between Main and CrOpenGL service */
-typedef struct VBOXVDMACMD_CHROMIUM_CTL_CRCONNECT {
-	VBOXVDMACMD_CHROMIUM_CTL Hdr;
-	/*input (filled by Client) :*/
-	/*class VMMDev*/void *pVMMDev;
-	VBOXCRCON_CLIENT_CALLBACKS ClientCallbacks;
-	/*output (filled by Server) :*/
-	VBOXCRCON_SERVER_CALLBACKS ServerCallbacks;
-} VBOXVDMACMD_CHROMIUM_CTL_CRCONNECT, *PVBOXVDMACMD_CHROMIUM_CTL_CRCONNECT;
-
-/* ring command buffer dr */
-#define VBOXCMDVBVA_STATE_SUBMITTED   1
-#define VBOXCMDVBVA_STATE_CANCELLED   2
-#define VBOXCMDVBVA_STATE_IN_PROGRESS 3
-/* the "completed" state is signalled via the ring buffer values */
-
-/* CrHgsmi command */
-#define VBOXCMDVBVA_OPTYPE_CRCMD                        1
-/* blit command that does blitting of allocations identified by VRAM offset or host id
- * for VRAM-offset ones the size and format are same as primary */
-#define VBOXCMDVBVA_OPTYPE_BLT                          2
-/* flip */
-#define VBOXCMDVBVA_OPTYPE_FLIP                         3
-/* ColorFill */
-#define VBOXCMDVBVA_OPTYPE_CLRFILL                      4
-/* allocation paging transfer request */
-#define VBOXCMDVBVA_OPTYPE_PAGING_TRANSFER              5
-/* allocation paging fill request */
-#define VBOXCMDVBVA_OPTYPE_PAGING_FILL                  6
-/* same as VBOXCMDVBVA_OPTYPE_NOP, but contains VBOXCMDVBVA_HDR data */
-#define VBOXCMDVBVA_OPTYPE_NOPCMD                       7
-/* actual command is stored in guest system memory */
-#define VBOXCMDVBVA_OPTYPE_SYSMEMCMD                    8
-/* complex command - i.e. can contain multiple commands
- * i.e. the VBOXCMDVBVA_OPTYPE_COMPLEXCMD VBOXCMDVBVA_HDR is followed
- * by one or more VBOXCMDVBVA_HDR commands.
- * Each command's size is specified in it's VBOXCMDVBVA_HDR's u32FenceID field */
-#define VBOXCMDVBVA_OPTYPE_COMPLEXCMD                   9
-
-/* nop - is a one-bit command. The buffer size to skip is determined by VBVA buffer size */
-#define VBOXCMDVBVA_OPTYPE_NOP                          0x80
-
-/* u8Flags flags */
-/* transfer from RAM to Allocation */
-#define VBOXCMDVBVA_OPF_PAGING_TRANSFER_IN                  0x80
-
-#define VBOXCMDVBVA_OPF_BLT_TYPE_SAMEDIM_A8R8G8B8           0
-#define VBOXCMDVBVA_OPF_BLT_TYPE_GENERIC_A8R8G8B8           1
-#define VBOXCMDVBVA_OPF_BLT_TYPE_OFFPRIMSZFMT_OR_ID         2
-
-#define VBOXCMDVBVA_OPF_BLT_TYPE_MASK                       3
-
-
-#define VBOXCMDVBVA_OPF_CLRFILL_TYPE_GENERIC_A8R8G8B8       0
-
-#define VBOXCMDVBVA_OPF_CLRFILL_TYPE_MASK                   1
-
-
-/* blit direction is from first operand to second */
-#define VBOXCMDVBVA_OPF_BLT_DIR_IN_2                        0x10
-/* operand 1 contains host id */
-#define VBOXCMDVBVA_OPF_OPERAND1_ISID                       0x20
-/* operand 2 contains host id */
-#define VBOXCMDVBVA_OPF_OPERAND2_ISID                       0x40
-/* primary hint id is src */
-#define VBOXCMDVBVA_OPF_PRIMARY_HINT_SRC                    0x80
-
-/* trying to make the header as small as possible,
- * we'd have pretty few op codes actually, so 8bit is quite enough,
- * we will be able to extend it in any way. */
-typedef struct VBOXCMDVBVA_HDR {
-	/* one VBOXCMDVBVA_OPTYPE_XXX, except NOP, see comments above */
-	u8 u8OpCode;
-	/* command-specific
-	 * VBOXCMDVBVA_OPTYPE_CRCMD                     - must be null
-	 * VBOXCMDVBVA_OPTYPE_BLT                       - OR-ed VBOXCMDVBVA_OPF_ALLOC_XXX flags
-	 * VBOXCMDVBVA_OPTYPE_PAGING_TRANSFER           - must be null
-	 * VBOXCMDVBVA_OPTYPE_PAGING_FILL               - must be null
-	 * VBOXCMDVBVA_OPTYPE_NOPCMD                    - must be null
-	 * VBOXCMDVBVA_OPTYPE_NOP                       - not applicable (as the entire VBOXCMDVBVA_HDR is not valid) */
-	u8 u8Flags;
-	/* one of VBOXCMDVBVA_STATE_XXX*/
-	volatile u8 u8State;
-	union {
-		/* result, 0 on success, otherwise contains the failure code TBD */
-		int8_t i8Result;
-		u8 u8PrimaryID;
-	} u;
-	union {
-		/* complex command (VBOXCMDVBVA_OPTYPE_COMPLEXCMD) element data */
-		struct {
-			/* command length */
-			u16 u16CbCmdHost;
-			/* guest-specific data, host expects it to be NULL */
-			u16 u16CbCmdGuest;
-		} complexCmdEl;
-		/* DXGK DDI fence ID */
-		u32 u32FenceID;
-	} u2;
-} VBOXCMDVBVA_HDR;
-
-typedef u32 VBOXCMDVBVAOFFSET;
-typedef uint64_t VBOXCMDVBVAPHADDR;
-typedef u32 VBOXCMDVBVAPAGEIDX;
-
-typedef struct VBOXCMDVBVA_CRCMD_BUFFER {
-	u32 buffer_length;
-	VBOXCMDVBVAOFFSET offBuffer;
-} VBOXCMDVBVA_CRCMD_BUFFER;
-
-typedef struct VBOXCMDVBVA_CRCMD_CMD {
-	u32 cBuffers;
-	VBOXCMDVBVA_CRCMD_BUFFER aBuffers[1];
-} VBOXCMDVBVA_CRCMD_CMD;
-
-typedef struct VBOXCMDVBVA_CRCMD {
-	VBOXCMDVBVA_HDR Hdr;
-	VBOXCMDVBVA_CRCMD_CMD Cmd;
-} VBOXCMDVBVA_CRCMD;
-
-typedef struct VBOXCMDVBVA_ALLOCINFO {
-	union {
-		VBOXCMDVBVAOFFSET offVRAM;
-		u32 id;
-	} u;
-} VBOXCMDVBVA_ALLOCINFO;
-
-typedef struct VBOXCMDVBVA_ALLOCDESC {
-	VBOXCMDVBVA_ALLOCINFO Info;
-	u16 u16Width;
-	u16 u16Height;
-} VBOXCMDVBVA_ALLOCDESC;
-
-typedef struct VBOXCMDVBVA_RECT {
-   /** Coordinates of affected rectangle. */
-   int16_t xLeft;
-   int16_t yTop;
-   int16_t xRight;
-   int16_t yBottom;
-} VBOXCMDVBVA_RECT;
-
-typedef struct VBOXCMDVBVA_POINT {
-   int16_t x;
-   int16_t y;
-} VBOXCMDVBVA_POINT;
-
-typedef struct VBOXCMDVBVA_BLT_HDR {
-	VBOXCMDVBVA_HDR Hdr;
-	VBOXCMDVBVA_POINT Pos;
-} VBOXCMDVBVA_BLT_HDR;
-
-typedef struct VBOXCMDVBVA_BLT_PRIMARY {
-	VBOXCMDVBVA_BLT_HDR Hdr;
-	VBOXCMDVBVA_ALLOCINFO alloc;
-	/* the rects count is determined from the command size */
-	VBOXCMDVBVA_RECT aRects[1];
-} VBOXCMDVBVA_BLT_PRIMARY;
-
-typedef struct VBOXCMDVBVA_BLT_PRIMARY_GENERIC_A8R8G8B8 {
-	VBOXCMDVBVA_BLT_HDR Hdr;
-	VBOXCMDVBVA_ALLOCDESC alloc;
-	/* the rects count is determined from the command size */
-	VBOXCMDVBVA_RECT aRects[1];
-} VBOXCMDVBVA_BLT_PRIMARY_GENERIC_A8R8G8B8;
-
-typedef struct VBOXCMDVBVA_BLT_OFFPRIMSZFMT_OR_ID {
-	VBOXCMDVBVA_BLT_HDR Hdr;
-	VBOXCMDVBVA_ALLOCINFO alloc;
-	u32 id;
-	/* the rects count is determined from the command size */
-	VBOXCMDVBVA_RECT aRects[1];
-} VBOXCMDVBVA_BLT_OFFPRIMSZFMT_OR_ID;
-
-typedef struct VBOXCMDVBVA_BLT_SAMEDIM_A8R8G8B8 {
-	VBOXCMDVBVA_BLT_HDR Hdr;
-	VBOXCMDVBVA_ALLOCDESC alloc1;
-	VBOXCMDVBVA_ALLOCINFO info2;
-	/* the rects count is determined from the command size */
-	VBOXCMDVBVA_RECT aRects[1];
-} VBOXCMDVBVA_BLT_SAMEDIM_A8R8G8B8;
-
-typedef struct VBOXCMDVBVA_BLT_GENERIC_A8R8G8B8 {
-	VBOXCMDVBVA_BLT_HDR Hdr;
-	VBOXCMDVBVA_ALLOCDESC alloc1;
-	VBOXCMDVBVA_ALLOCDESC alloc2;
-	/* the rects count is determined from the command size */
-	VBOXCMDVBVA_RECT aRects[1];
-} VBOXCMDVBVA_BLT_GENERIC_A8R8G8B8;
-
-#define VBOXCMDVBVA_SIZEOF_BLTSTRUCT_MAX (sizeof (VBOXCMDVBVA_BLT_GENERIC_A8R8G8B8))
-
-typedef struct VBOXCMDVBVA_FLIP {
-	VBOXCMDVBVA_HDR Hdr;
-	VBOXCMDVBVA_ALLOCINFO src;
-	VBOXCMDVBVA_RECT aRects[1];
-} VBOXCMDVBVA_FLIP;
-
-#define VBOXCMDVBVA_SIZEOF_FLIPSTRUCT_MIN (RT_OFFSETOF(VBOXCMDVBVA_FLIP, aRects))
-
-typedef struct VBOXCMDVBVA_CLRFILL_HDR {
-	VBOXCMDVBVA_HDR Hdr;
-	u32 u32Color;
-} VBOXCMDVBVA_CLRFILL_HDR;
-
-typedef struct VBOXCMDVBVA_CLRFILL_PRIMARY {
-	VBOXCMDVBVA_CLRFILL_HDR Hdr;
-	VBOXCMDVBVA_RECT aRects[1];
-} VBOXCMDVBVA_CLRFILL_PRIMARY;
-
-typedef struct VBOXCMDVBVA_CLRFILL_GENERIC_A8R8G8B8 {
-	VBOXCMDVBVA_CLRFILL_HDR Hdr;
-	VBOXCMDVBVA_ALLOCDESC dst;
-	VBOXCMDVBVA_RECT aRects[1];
-} VBOXCMDVBVA_CLRFILL_GENERIC_A8R8G8B8;
-
-#define VBOXCMDVBVA_SIZEOF_CLRFILLSTRUCT_MAX (sizeof (VBOXCMDVBVA_CLRFILL_GENERIC_A8R8G8B8))
-
-#if 0
-#define VBOXCMDVBVA_SYSMEMEL_CPAGES_MAX  0x1000
-
-typedef struct VBOXCMDVBVA_SYSMEMEL {
-	u32 cPagesAfterFirst  : 12;
-	u32 iPage1            : 20;
-	u32 iPage2;
-} VBOXCMDVBVA_SYSMEMEL;
-#endif
-
-typedef struct VBOXCMDVBVA_PAGING_TRANSFER_DATA {
-	/* for now can only contain offVRAM.
-	 * paging transfer can NOT be initiated for allocations having host 3D object (hostID) associated */
-	VBOXCMDVBVA_ALLOCINFO Alloc;
-	VBOXCMDVBVAPAGEIDX aPageNumbers[1];
-} VBOXCMDVBVA_PAGING_TRANSFER_DATA;
-
-typedef struct VBOXCMDVBVA_PAGING_TRANSFER {
-	VBOXCMDVBVA_HDR Hdr;
-	VBOXCMDVBVA_PAGING_TRANSFER_DATA Data;
-} VBOXCMDVBVA_PAGING_TRANSFER;
-
-typedef struct VBOXCMDVBVA_PAGING_FILL {
-	VBOXCMDVBVA_HDR Hdr;
-	u32 u32CbFill;
-	u32 u32Pattern;
-	/* paging transfer can NOT be initiated for allocations having host 3D object (hostID) associated */
-	VBOXCMDVBVAOFFSET offVRAM;
-} VBOXCMDVBVA_PAGING_FILL;
-
-typedef struct VBOXCMDVBVA_SYSMEMCMD {
-	VBOXCMDVBVA_HDR Hdr;
-	VBOXCMDVBVAPHADDR phCmd;
-} VBOXCMDVBVA_SYSMEMCMD;
-
-#define VBOXCMDVBVACTL_TYPE_ENABLE     1
-#define VBOXCMDVBVACTL_TYPE_3DCTL      2
-#define VBOXCMDVBVACTL_TYPE_RESIZE     3
-
-typedef struct VBOXCMDVBVA_CTL {
-	u32 u32Type;
-	s32 result;
-} VBOXCMDVBVA_CTL;
-
-typedef struct VBOXCMDVBVA_CTL_ENABLE {
-	VBOXCMDVBVA_CTL Hdr;
-	VBVAENABLE Enable;
-} VBOXCMDVBVA_CTL_ENABLE;
-
 #define VBOXCMDVBVA_SCREENMAP_SIZE(_elType) ((VBOX_VIDEO_MAX_SCREENS + sizeof (_elType) - 1) / sizeof (_elType))
 #define VBOXCMDVBVA_SCREENMAP_DECL(_elType, _name) _elType _name[VBOXCMDVBVA_SCREENMAP_SIZE(_elType)]
 
-typedef struct VBOXCMDVBVA_RESIZE_ENTRY {
-	VBVAINFOSCREEN Screen;
-	VBOXCMDVBVA_SCREENMAP_DECL(u32, aTargetMap);
-} VBOXCMDVBVA_RESIZE_ENTRY;
-
-typedef struct VBOXCMDVBVA_RESIZE {
-	VBOXCMDVBVA_RESIZE_ENTRY aEntries[1];
-} VBOXCMDVBVA_RESIZE;
-
-typedef struct VBOXCMDVBVA_CTL_RESIZE {
-	VBOXCMDVBVA_CTL Hdr;
-	VBOXCMDVBVA_RESIZE Resize;
-} VBOXCMDVBVA_CTL_RESIZE;
-
-#define VBOXCMDVBVA3DCTL_TYPE_CONNECT     1
-#define VBOXCMDVBVA3DCTL_TYPE_DISCONNECT  2
-#define VBOXCMDVBVA3DCTL_TYPE_CMD         3
-
-typedef struct VBOXCMDVBVA_3DCTL {
-	u32 u32Type;
-	u32 u32CmdClientId;
-} VBOXCMDVBVA_3DCTL;
-
-typedef struct VBOXCMDVBVA_3DCTL_CONNECT {
-	VBOXCMDVBVA_3DCTL Hdr;
-	u32 u32MajorVersion;
-	u32 u32MinorVersion;
-	uint64_t u64Pid;
-} VBOXCMDVBVA_3DCTL_CONNECT;
-
-typedef struct VBOXCMDVBVA_3DCTL_CMD {
-	VBOXCMDVBVA_3DCTL Hdr;
-	VBOXCMDVBVA_HDR Cmd;
-} VBOXCMDVBVA_3DCTL_CMD;
-
-typedef struct VBOXCMDVBVA_CTL_3DCTL_CMD {
-	VBOXCMDVBVA_CTL Hdr;
-	VBOXCMDVBVA_3DCTL_CMD Cmd;
-} VBOXCMDVBVA_CTL_3DCTL_CMD;
-
-typedef struct VBOXCMDVBVA_CTL_3DCTL_CONNECT {
-	VBOXCMDVBVA_CTL Hdr;
-	VBOXCMDVBVA_3DCTL_CONNECT Connect;
-} VBOXCMDVBVA_CTL_3DCTL_CONNECT;
-
-typedef struct VBOXCMDVBVA_CTL_3DCTL {
-	VBOXCMDVBVA_CTL Hdr;
-	VBOXCMDVBVA_3DCTL Ctl;
-} VBOXCMDVBVA_CTL_3DCTL;
-
-#pragma pack()
-
-
-#ifdef VBOXVDMA_WITH_VBVA
-# pragma pack(1)
-
-typedef struct VBOXVDMAVBVACMD {
-	u32 offCmd;
-} VBOXVDMAVBVACMD;
-
-#pragma pack()
-#endif
-
 #endif /* !VBOX_INCLUDED_Graphics_VBoxVideo_h */
 
